@@ -1,14 +1,26 @@
 import mimetypes
 import os.path
+import random
+import string
 
 from django.core.files.storage import default_storage
 from django.template.defaultfilters import slugify
 
 
 def slugify_filename(filename):
-    u""" Slugify filename """
+    """ Slugify filename """
     name, ext = os.path.splitext(filename)
-    return slugify(name) + ext
+    slugified = get_slugified_name(name)
+    return slugified + ext
+
+
+def get_slugified_name(filename):
+    slugified = slugify(filename)
+    return slugified or get_random_string()
+
+
+def get_random_string():
+    return ''.join(random.sample(string.ascii_lowercase*6, 6))
 
 
 def get_thumb_filename(file_name):
@@ -16,7 +28,7 @@ def get_thumb_filename(file_name):
     Generate thumb filename by adding _thumb to end of
     filename before . (if present)
     """
-    return '{0}_thumb{1}'.format(*os.path.splitext(file_name))
+    return u'{0}_thumb{1}'.format(*os.path.splitext(file_name))
 
 
 def get_image_format(extension):
